@@ -1,13 +1,12 @@
-import pytest
-
 from flycs_sdk.custom_code import Dependency
-from flycs_sdk.query_base_schema import UnsupportedMode, UnsupportedType
 from flycs_sdk.transformations import (
     FieldConfig,
-    SchemaUpdateOptions,
     Transformation,
     WriteDisposition,
+    SchemaUpdateOptions,
+    FieldConfig,
 )
+import pytest
 
 transformation_name = "my_tranformation"
 transformation_query = "SELECT * FROM TABLE;"
@@ -25,8 +24,8 @@ transformation_dependencies = [Dependency("entity1", "staging", "deps")]
 transformation_parsing_dependencies = []
 transformation_destroy_table = False
 transformation_fields_config = [
-    FieldConfig(name="field1", decrypt=False, type="STRING", mode="NULLABLE"),
-    FieldConfig(name="field2", decrypt=True, type="DATE", mode="NULLABLE"),
+    FieldConfig(field_name="field1", decrypt=False),
+    FieldConfig(field_name="field2", decrypt=True),
 ]
 transformation_force_cache_refresh = True
 
@@ -50,7 +49,7 @@ class TestTranformations:
             dependencies=transformation_dependencies,
             parsing_dependencies=transformation_parsing_dependencies,
             destroy_table=transformation_destroy_table,
-            schema=transformation_fields_config,
+            fields_config=transformation_fields_config,
             force_cache_refresh=transformation_force_cache_refresh,
         )
 
@@ -71,7 +70,7 @@ class TestTranformations:
         )
         assert my_transformation.dependencies == transformation_dependencies
         assert my_transformation.destroy_table == transformation_destroy_table
-        assert my_transformation.schema == transformation_fields_config
+        assert my_transformation.fields_config == transformation_fields_config
         assert (
             my_transformation.force_cache_refresh == transformation_force_cache_refresh
         )
@@ -100,20 +99,14 @@ class TestTranformations:
             "DESTROY_TABLE": False,
             "TABLES": None,
             "KIND": "transformation",
-            "SCHEMA": [
+            "FIELDS_CONFIG": [
                 {
-                    "NAME": "field1",
+                    "FIELD_NAME": "field1",
                     "DECRYPT": False,
-                    "TYPE": "STRING",
-                    "MODE": "NULLABLE",
-                    "FIELDS": [],
                 },
                 {
-                    "NAME": "field2",
+                    "FIELD_NAME": "field2",
                     "DECRYPT": True,
-                    "TYPE": "DATE",
-                    "MODE": "NULLABLE",
-                    "FIELDS": [],
                 },
             ],
             "FORCE_CACHE_REFRESH": transformation_force_cache_refresh,
